<?php
$OPTIONS['helper'] = array(
    'show' => 'helper_show',
    );

function helper_show(&$args, $dom) {
    $helper_info_text = cache_get('', 'wiki-helper-info');
    if($helper_info_text === false || !empty($args['dump'])) {
	$helper_info = helper_make_info();
	$helper_info_text = json_encode($helper_info);
	cache_create('', 'wiki-helper-info', $helper_info_text);

	if(!empty($args['dump'])) {
	    pprint_r($helper_info);
	    exit(0);
	}
    }
    

    header("Content-Type: application/json; charset=utf-8");
    echo($helper_info_text);
    exit(0);
}

function helper_make_info() {
    global $WIKI_OPERATORS_INLINE;
    global $WIKI_OPERATORS_LINE_HEAD;
    global $WIKI_OPERATORS_FUNCTION;
    global $WIKI_ALIASES;
    global $WIKI_ENTITY_REFERENCES;
    global $WIKI_ENTITY_IMAGES;

    $completion_candidates = array(); 

    $function_names = array();
    $function_names = array_merge($function_names, array_keys($WIKI_OPERATORS_FUNCTION));
    $function_names = array_merge($function_names, array_keys($WIKI_ALIASES));

    $manual_pages = manual_parse();

    $manual_pages_exists = true;
    $cheat_sheet_page_names = array(
	MANUAL_PAGENAME . '/' . LANG . '/Wiki/CheatSheet/Function',
	MANUAL_PAGENAME . '/' . LANG . '/Wiki/CheatSheet/FunctionAdvanced',
	);
    foreach($cheat_sheet_page_names as $cheat_sheet_page_name) {
	if(!isset($manual_pages[$cheat_sheet_page_name]))
	    continue;
	$dom = dom_create_document();
	if(!page_is_exists($cheat_sheet_page_name)) {
	    $manual_pages_exists = false;
	}
	
	$page = page_read($cheat_sheet_page_name);
	wiki_convert($page, $dom, $manual_pages[$cheat_sheet_page_name]['body']);

	$xpath = new DOMXPath(dom_owner($dom));
	$trs = $xpath->query('//tbody/tr');
	if(!is_null($trs)) {
	    foreach($trs as $tr) {
		if($tr->childNodes->length == 2) {
		    $example = trim(dom_text($tr->firstChild->nextSibling));
		    $examples = preg_split('/\bor\b/i', $example, -1, PREG_SPLIT_NO_EMPTY);
		    $examples = array_map('trim', $examples);

		    foreach($function_names as $function_name) {
			$pattern = '&' . $function_name;
			if(preg_match('/^' . $pattern . '\b/', $example)) {
			    $completion_candidates[$pattern] = 
				array(
				    'description' => rtrim(dom_text($tr->firstChild)),
				    'examples' => $examples
				    );
			}
		    }
		    
		}
	    }
	}
    }

    foreach(array_keys($WIKI_ENTITY_IMAGES) as $name) {
	$src = '&' . $name . ';';
	$html_name = htmlspecialchars($name);
	$completion_candidates[$src] = 
	    array(
		'display' => '<i class="entity '  . $html_name . '">' . $html_name .'</i>',
		'examples' => array($src)
		);
    }

    /*
    foreach(array_keys($WIKI_ENTITY_REFERENCES) as $name) {
	$src = '&' . $name . ';';
	$completion_candidates[$src] = 
	    array(
		'display' => $src,
		'examples' => array($src)
		);
    }
    */

    ksort($completion_candidates);
    $helper_info = array(
	'completion' => array(
	    'candidates' => $completion_candidates,
	    'maxlength' => max(array_map('strlen', array_keys($completion_candidates))),
	    ),
	);
    if($manual_pages_exists) {
	$helper_info['manual_url'] = url_make(MANUAL_PAGENAME . '/' . LANG);
    } else {
	$helper_info['manual_url'] = OFFICIAL_URL . '?' . url_path_encode(MANUAL_PAGENAME . '/' . LANG);
    }
    return $helper_info;
}

?>